[![Build/Test](https://github.com/software-students-spring2025/3-python-package-pyke-ult/actions/workflows/test.yml/badge.svg)](https://github.com/software-students-spring2025/3-python-package-pyke-ult/actions/workflows/test.yml)

# pykeafortune

## Description

[pykeafortune](https://pypi.org/project/pykeafortune/) is a Python package containing functions to find your horoscope, lucky day, lucky number, and fortune cookie fortune when you want to boost your luck and discover any upcoming fortune.

## How to Import and Use pykeafortune

## How to Contribute to pykeafortune

## How to Configure and Run Your Project

## Contributors:
[Matthew Cheng](https://github.com/mattchng)

[Maya Felix](https://github.com/mxf4596)

[James Hou](https://github.com/James-Hou22)

[Larry Yang](https://github.com/larryyang04)
